function [LoV,DxDoV,LpoVp,BxboVp,xo,yo]=oplines(R,q,xf,xd,xb)
% Oplines - Calculate vectors for plotting operating lines.
% function [LoV,DxDoV,LpoVp,BxboVp,xo,yo]=oplines(R,q,xf,xd,xb)
% Binary Ideal Distillation
% R is the relux ratio: L/D
% q is the fraction vapor in the feed
% xf, xd, xb are the mol fractions of the 1st compound
%     in the feed, distillate & bottoms.
% LoV = L/V
% DxDoV = D*xd/V
% Top op line: y=LoV*x+DxDoV
% LpoVp = Lp/Vp
% BxboVp = B*xb/Vp
% Bottom op line = y=LpoVp*x-BxboVp
% xo and yo vectors to plot for operating lines.
[B,D,V,L,Vp,Lp]=bidist(R,q,xf,xd,xb);
LoV = L/V;
DxDoV = D*xd/V;
LpoVp = Lp/Vp;
BxboVp = B*xb/Vp;
xi=(DxDoV+BxboVp)/(LpoVp-LoV);
yi=LoV*xi+DxDoV;
xo=[xb,xi,xd];
yo=[xb,yi,xd];

